Welcome to mirror list, hosted at ThFree Co, Russian Federation.

git.blender.org/blender-addons.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
Diffstat (limited to 'io_import_scene_unreal_psa_psk.py')
-rw-r--r--io_import_scene_unreal_psa_psk.py6
1 files changed, 3 insertions, 3 deletions
diff --git a/io_import_scene_unreal_psa_psk.py b/io_import_scene_unreal_psa_psk.py
index c210b771..5fb0c8f6 100644
--- a/io_import_scene_unreal_psa_psk.py
+++ b/io_import_scene_unreal_psa_psk.py
@@ -89,10 +89,10 @@ class md5_bone:
self.scale = [0.0] * 3
self.head = [0.0] * 3
self.tail = [0.0] * 3
- self.bindmat = [None] * 3 # is this how you initilize a 2d-array
+ self.bindmat = [None] * 3 # is this how you initialize a 2d-array
for i in range(3):
self.bindmat[i] = [0.0] * 3
- self.origmat = [None] * 3 #is this how you initilize a 2d-array
+ self.origmat = [None] * 3 #is this how you initialize a 2d-array
for i in range(3):
self.origmat[i] = [0.0] * 3
self.parent = ""
@@ -628,7 +628,7 @@ def pskimport(infile,importmesh,importbone,bDebugLogPSK,importmultiuvtextures):
print("INIT UV TEXTURE...")
_matcount = 0
#for mattexcount in materials:
- #print("MATERAIL ID:", _matcount)
+ #print("MATERIAL ID:", _matcount)
_textcount = 0
for uv in me_ob.tessface_uv_textures: # uv texture
print("UV TEXTURE ID:",_textcount)